@@ -2,9 +2,12 @@ from wagtail.core.signals import page_published, page_unpublished
 
 
 def handle_publish(sender, instance, **kwargs):
+    from webspace.bakery.models import VersionBuild
     from .abstract import WagtailPageBakeryModel
     if isinstance(instance, WagtailPageBakeryModel):
         instance.build()
+        vb = VersionBuild.get()
+        vb.minor()
 
 
 def handle_unpublish(sender, instance, **kwargs):
